/****************************************************************************
** Meta object code from reading C++ file 'widgetbasedpoller.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kidletime-5.39.0/src/widgetbasedpoller.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'widgetbasedpoller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_WidgetBasedPoller_t {
    QByteArrayData data[15];
    char stringdata0[198];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_WidgetBasedPoller_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_WidgetBasedPoller_t qt_meta_stringdata_WidgetBasedPoller = {
    {
QT_MOC_LITERAL(0, 0, 17), // "WidgetBasedPoller"
QT_MOC_LITERAL(1, 18, 10), // "addTimeout"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 11), // "nextTimeout"
QT_MOC_LITERAL(4, 42, 13), // "removeTimeout"
QT_MOC_LITERAL(5, 56, 8), // "timeouts"
QT_MOC_LITERAL(6, 65, 10), // "QList<int>"
QT_MOC_LITERAL(7, 76, 16), // "forcePollRequest"
QT_MOC_LITERAL(8, 93, 14), // "catchIdleEvent"
QT_MOC_LITERAL(9, 108, 22), // "stopCatchingIdleEvents"
QT_MOC_LITERAL(10, 131, 4), // "poll"
QT_MOC_LITERAL(11, 136, 11), // "getIdleTime"
QT_MOC_LITERAL(12, 148, 16), // "detectedActivity"
QT_MOC_LITERAL(13, 165, 15), // "waitForActivity"
QT_MOC_LITERAL(14, 181, 16) // "releaseInputLock"

    },
    "WidgetBasedPoller\0addTimeout\0\0nextTimeout\0"
    "removeTimeout\0timeouts\0QList<int>\0"
    "forcePollRequest\0catchIdleEvent\0"
    "stopCatchingIdleEvents\0poll\0getIdleTime\0"
    "detectedActivity\0waitForActivity\0"
    "releaseInputLock"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_WidgetBasedPoller[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x0a /* Public */,
       4,    1,   72,    2, 0x0a /* Public */,
       5,    0,   75,    2, 0x0a /* Public */,
       7,    0,   76,    2, 0x0a /* Public */,
       8,    0,   77,    2, 0x0a /* Public */,
       9,    0,   78,    2, 0x0a /* Public */,
      10,    0,   79,    2, 0x08 /* Private */,
      11,    0,   80,    2, 0x08 /* Private */,
      12,    0,   81,    2, 0x08 /* Private */,
      13,    0,   82,    2, 0x08 /* Private */,
      14,    0,   83,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    0x80000000 | 6,
    QMetaType::Int,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Int,
    QMetaType::Int,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void WidgetBasedPoller::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WidgetBasedPoller *_t = static_cast<WidgetBasedPoller *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->addTimeout((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->removeTimeout((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: { QList<int> _r = _t->timeouts();
            if (_a[0]) *reinterpret_cast< QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->forcePollRequest();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->catchIdleEvent(); break;
        case 5: _t->stopCatchingIdleEvents(); break;
        case 6: { int _r = _t->poll();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->getIdleTime();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->detectedActivity(); break;
        case 9: _t->waitForActivity(); break;
        case 10: _t->releaseInputLock(); break;
        default: ;
        }
    }
}

const QMetaObject WidgetBasedPoller::staticMetaObject = {
    { &AbstractSystemPoller::staticMetaObject, qt_meta_stringdata_WidgetBasedPoller.data,
      qt_meta_data_WidgetBasedPoller,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *WidgetBasedPoller::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WidgetBasedPoller::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_WidgetBasedPoller.stringdata0))
        return static_cast<void*>(this);
    return AbstractSystemPoller::qt_metacast(_clname);
}

int WidgetBasedPoller::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractSystemPoller::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
