/****************************************************************************
** Meta object code from reading C++ file 'kidletime.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kidletime-5.39.0/src/kidletime.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kidletime.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KIdleTime_t {
    QByteArrayData data[13];
    char stringdata0[197];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KIdleTime_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KIdleTime_t qt_meta_stringdata_KIdleTime = {
    {
QT_MOC_LITERAL(0, 0, 9), // "KIdleTime"
QT_MOC_LITERAL(1, 10, 16), // "resumingFromIdle"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 14), // "timeoutReached"
QT_MOC_LITERAL(4, 43, 10), // "identifier"
QT_MOC_LITERAL(5, 54, 4), // "msec"
QT_MOC_LITERAL(6, 59, 14), // "addIdleTimeout"
QT_MOC_LITERAL(7, 74, 17), // "removeIdleTimeout"
QT_MOC_LITERAL(8, 92, 21), // "removeAllIdleTimeouts"
QT_MOC_LITERAL(9, 114, 20), // "catchNextResumeEvent"
QT_MOC_LITERAL(10, 135, 23), // "stopCatchingResumeEvent"
QT_MOC_LITERAL(11, 159, 19), // "_k_resumingFromIdle"
QT_MOC_LITERAL(12, 179, 17) // "_k_timeoutReached"

    },
    "KIdleTime\0resumingFromIdle\0\0timeoutReached\0"
    "identifier\0msec\0addIdleTimeout\0"
    "removeIdleTimeout\0removeAllIdleTimeouts\0"
    "catchNextResumeEvent\0stopCatchingResumeEvent\0"
    "_k_resumingFromIdle\0_k_timeoutReached"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KIdleTime[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x06 /* Public */,
       3,    1,   65,    2, 0x06 /* Public */,
       3,    2,   68,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   73,    2, 0x0a /* Public */,
       7,    1,   76,    2, 0x0a /* Public */,
       8,    0,   79,    2, 0x0a /* Public */,
       9,    0,   80,    2, 0x0a /* Public */,
      10,    0,   81,    2, 0x0a /* Public */,
      11,    0,   82,    2, 0x08 /* Private */,
      12,    1,   83,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    4,    5,

 // slots: parameters
    QMetaType::Int, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void KIdleTime::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KIdleTime *_t = static_cast<KIdleTime *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->resumingFromIdle(); break;
        case 1: _t->timeoutReached((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->timeoutReached((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 3: { int _r = _t->addIdleTimeout((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->removeIdleTimeout((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->removeAllIdleTimeouts(); break;
        case 6: _t->catchNextResumeEvent(); break;
        case 7: _t->stopCatchingResumeEvent(); break;
        case 8: _t->d_func()->_k_resumingFromIdle(); break;
        case 9: _t->d_func()->_k_timeoutReached((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (KIdleTime::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KIdleTime::resumingFromIdle)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KIdleTime::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KIdleTime::timeoutReached)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KIdleTime::*_t)(int , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&KIdleTime::timeoutReached)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KIdleTime::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_KIdleTime.data,
      qt_meta_data_KIdleTime,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KIdleTime::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KIdleTime::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KIdleTime.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KIdleTime::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KIdleTime::resumingFromIdle()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KIdleTime::timeoutReached(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KIdleTime::timeoutReached(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
