/****************************************************************************
** Meta object code from reading C++ file 'xscreensaverbasedpoller.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/kidletime-5.39.0/src/plugins/xscreensaver/xscreensaverbasedpoller.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xscreensaverbasedpoller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_XScreensaverBasedPoller_t {
    QByteArrayData data[6];
    char stringdata0[89];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XScreensaverBasedPoller_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XScreensaverBasedPoller_t qt_meta_stringdata_XScreensaverBasedPoller = {
    {
QT_MOC_LITERAL(0, 0, 23), // "XScreensaverBasedPoller"
QT_MOC_LITERAL(1, 24, 20), // "simulateUserActivity"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 20), // "screensaverActivated"
QT_MOC_LITERAL(4, 67, 9), // "activated"
QT_MOC_LITERAL(5, 77, 11) // "getIdleTime"

    },
    "XScreensaverBasedPoller\0simulateUserActivity\0"
    "\0screensaverActivated\0activated\0"
    "getIdleTime"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XScreensaverBasedPoller[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x0a /* Public */,
       3,    1,   30,    2, 0x08 /* Private */,
       5,    0,   33,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Int,

       0        // eod
};

void XScreensaverBasedPoller::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        XScreensaverBasedPoller *_t = static_cast<XScreensaverBasedPoller *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->simulateUserActivity(); break;
        case 1: _t->screensaverActivated((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: { int _r = _t->getIdleTime();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject XScreensaverBasedPoller::staticMetaObject = {
    { &WidgetBasedPoller::staticMetaObject, qt_meta_stringdata_XScreensaverBasedPoller.data,
      qt_meta_data_XScreensaverBasedPoller,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *XScreensaverBasedPoller::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XScreensaverBasedPoller::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XScreensaverBasedPoller.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "org.kde.kidletime.AbstractSystemPoller"))
        return static_cast< AbstractSystemPoller*>(this);
    return WidgetBasedPoller::qt_metacast(_clname);
}

int XScreensaverBasedPoller::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WidgetBasedPoller::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

QT_PLUGIN_METADATA_SECTION const uint qt_section_alignment_dummy = 42;

#ifdef QT_NO_DEBUG

QT_PLUGIN_METADATA_SECTION
static const unsigned char qt_pluginMetaData[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', ' ',
    'q',  'b',  'j',  's',  0x01, 0x00, 0x00, 0x00,
    0xe4, 0x00, 0x00, 0x00, 0x0b, 0x00, 0x00, 0x00,
    0xd0, 0x00, 0x00, 0x00, 0x1b, 0x03, 0x00, 0x00,
    0x03, 0x00, 'I',  'I',  'D',  0x00, 0x00, 0x00,
    '&',  0x00, 'o',  'r',  'g',  '.',  'k',  'd', 
    'e',  '.',  'k',  'i',  'd',  'l',  'e',  't', 
    'i',  'm',  'e',  '.',  'A',  'b',  's',  't', 
    'r',  'a',  'c',  't',  'S',  'y',  's',  't', 
    'e',  'm',  'P',  'o',  'l',  'l',  'e',  'r', 
    0x1b, 0x0a, 0x00, 0x00, 0x09, 0x00, 'c',  'l', 
    'a',  's',  's',  'N',  'a',  'm',  'e',  0x00,
    0x17, 0x00, 'X',  'S',  'c',  'r',  'e',  'e', 
    'n',  's',  'a',  'v',  'e',  'r',  'B',  'a', 
    's',  'e',  'd',  'P',  'o',  'l',  'l',  'e', 
    'r',  0x00, 0x00, 0x00, 'Z',  ' ',  0xa1, 0x00,
    0x07, 0x00, 'v',  'e',  'r',  's',  'i',  'o', 
    'n',  0x00, 0x00, 0x00, 0x11, 0x00, 0x00, 0x00,
    0x05, 0x00, 'd',  'e',  'b',  'u',  'g',  0x00,
    0x15, 0x13, 0x00, 0x00, 0x08, 0x00, 'M',  'e', 
    't',  'a',  'D',  'a',  't',  'a',  0x00, 0x00,
    '8',  0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00,
    '4',  0x00, 0x00, 0x00, 0x94, 0x03, 0x00, 0x00,
    0x09, 0x00, 'p',  'l',  'a',  't',  'f',  'o', 
    'r',  'm',  's',  0x00, 0x18, 0x00, 0x00, 0x00,
    0x02, 0x00, 0x00, 0x00, 0x14, 0x00, 0x00, 0x00,
    0x03, 0x00, 'x',  'c',  'b',  0x00, 0x00, 0x00,
    0x8b, 0x01, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x00,
    0x0c, 0x00, 0x00, 0x00, 0x88, 0x00, 0x00, 0x00,
    '@',  0x00, 0x00, 0x00, '|',  0x00, 0x00, 0x00,
    'l',  0x00, 0x00, 0x00
};

#else // QT_NO_DEBUG

QT_PLUGIN_METADATA_SECTION
static const unsigned char qt_pluginMetaData[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', ' ',
    'q',  'b',  'j',  's',  0x01, 0x00, 0x00, 0x00,
    0xe4, 0x00, 0x00, 0x00, 0x0b, 0x00, 0x00, 0x00,
    0xd0, 0x00, 0x00, 0x00, 0x1b, 0x03, 0x00, 0x00,
    0x03, 0x00, 'I',  'I',  'D',  0x00, 0x00, 0x00,
    '&',  0x00, 'o',  'r',  'g',  '.',  'k',  'd', 
    'e',  '.',  'k',  'i',  'd',  'l',  'e',  't', 
    'i',  'm',  'e',  '.',  'A',  'b',  's',  't', 
    'r',  'a',  'c',  't',  'S',  'y',  's',  't', 
    'e',  'm',  'P',  'o',  'l',  'l',  'e',  'r', 
    0x15, 0x0a, 0x00, 0x00, 0x08, 0x00, 'M',  'e', 
    't',  'a',  'D',  'a',  't',  'a',  0x00, 0x00,
    '8',  0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00,
    '4',  0x00, 0x00, 0x00, 0x94, 0x03, 0x00, 0x00,
    0x09, 0x00, 'p',  'l',  'a',  't',  'f',  'o', 
    'r',  'm',  's',  0x00, 0x18, 0x00, 0x00, 0x00,
    0x02, 0x00, 0x00, 0x00, 0x14, 0x00, 0x00, 0x00,
    0x03, 0x00, 'x',  'c',  'b',  0x00, 0x00, 0x00,
    0x8b, 0x01, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x00,
    0x1b, 0x13, 0x00, 0x00, 0x09, 0x00, 'c',  'l', 
    'a',  's',  's',  'N',  'a',  'm',  'e',  0x00,
    0x17, 0x00, 'X',  'S',  'c',  'r',  'e',  'e', 
    'n',  's',  'a',  'v',  'e',  'r',  'B',  'a', 
    's',  'e',  'd',  'P',  'o',  'l',  'l',  'e', 
    'r',  0x00, 0x00, 0x00, '1',  0x00, 0x00, 0x00,
    0x05, 0x00, 'd',  'e',  'b',  'u',  'g',  0x00,
    'Z',  ' ',  0xa1, 0x00, 0x07, 0x00, 'v',  'e', 
    'r',  's',  'i',  'o',  'n',  0x00, 0x00, 0x00,
    0x0c, 0x00, 0x00, 0x00, '@',  0x00, 0x00, 0x00,
    0x88, 0x00, 0x00, 0x00, 0xb4, 0x00, 0x00, 0x00,
    0xc0, 0x00, 0x00, 0x00
};
#endif // QT_NO_DEBUG

QT_MOC_EXPORT_PLUGIN(XScreensaverBasedPoller, XScreensaverBasedPoller)

QT_WARNING_POP
QT_END_MOC_NAMESPACE
