/****************************************************************************
** Meta object code from reading C++ file 'abstractsystempoller.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kidletime-5.39.0/src/abstractsystempoller.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractsystempoller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_AbstractSystemPoller_t {
    QByteArrayData data[14];
    char stringdata0[192];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AbstractSystemPoller_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AbstractSystemPoller_t qt_meta_stringdata_AbstractSystemPoller = {
    {
QT_MOC_LITERAL(0, 0, 20), // "AbstractSystemPoller"
QT_MOC_LITERAL(1, 21, 16), // "resumingFromIdle"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 14), // "timeoutReached"
QT_MOC_LITERAL(4, 54, 4), // "msec"
QT_MOC_LITERAL(5, 59, 10), // "addTimeout"
QT_MOC_LITERAL(6, 70, 11), // "nextTimeout"
QT_MOC_LITERAL(7, 82, 13), // "removeTimeout"
QT_MOC_LITERAL(8, 96, 8), // "timeouts"
QT_MOC_LITERAL(9, 105, 10), // "QList<int>"
QT_MOC_LITERAL(10, 116, 16), // "forcePollRequest"
QT_MOC_LITERAL(11, 133, 14), // "catchIdleEvent"
QT_MOC_LITERAL(12, 148, 22), // "stopCatchingIdleEvents"
QT_MOC_LITERAL(13, 171, 20) // "simulateUserActivity"

    },
    "AbstractSystemPoller\0resumingFromIdle\0"
    "\0timeoutReached\0msec\0addTimeout\0"
    "nextTimeout\0removeTimeout\0timeouts\0"
    "QList<int>\0forcePollRequest\0catchIdleEvent\0"
    "stopCatchingIdleEvents\0simulateUserActivity"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AbstractSystemPoller[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    1,   60,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   63,    2, 0x0a /* Public */,
       7,    1,   66,    2, 0x0a /* Public */,
       8,    0,   69,    2, 0x0a /* Public */,
      10,    0,   70,    2, 0x0a /* Public */,
      11,    0,   71,    2, 0x0a /* Public */,
      12,    0,   72,    2, 0x0a /* Public */,
      13,    0,   73,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,    6,
    0x80000000 | 9,
    QMetaType::Int,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void AbstractSystemPoller::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        AbstractSystemPoller *_t = static_cast<AbstractSystemPoller *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->resumingFromIdle(); break;
        case 1: _t->timeoutReached((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->addTimeout((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->removeTimeout((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: { QList<int> _r = _t->timeouts();
            if (_a[0]) *reinterpret_cast< QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->forcePollRequest();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->catchIdleEvent(); break;
        case 7: _t->stopCatchingIdleEvents(); break;
        case 8: _t->simulateUserActivity(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (AbstractSystemPoller::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractSystemPoller::resumingFromIdle)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (AbstractSystemPoller::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&AbstractSystemPoller::timeoutReached)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject AbstractSystemPoller::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_AbstractSystemPoller.data,
      qt_meta_data_AbstractSystemPoller,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *AbstractSystemPoller::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractSystemPoller::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AbstractSystemPoller.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractSystemPoller::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void AbstractSystemPoller::resumingFromIdle()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AbstractSystemPoller::timeoutReached(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
